# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-23 08:29
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_file_form', '0003_auto_20170317_1230'),
    ]

    operations = [
        migrations.AlterIndexTogether(
            name='uploadedfile',
            index_together=set([('form_id', 'field_name')]),
        ),
    ]
